@@ -1,3 +1,4 @@
+"""Main package"""
 import pytest
 import pkg_resources
 import micromagneticmodel.abstract
@@ -11,11 +12,20 @@ from .evolver import Evolver
 from .driver import Driver
 from .system import System
 
+__version__ = pkg_resources.get_distribution(__name__).version
+
 
 def test():
+    """Run all package tests.
+
+    Examples
+    --------
+    1. Run all tests.
+
+    >>> import micromagneticmodel
+    ...
+    >>> # micromagneticmodel.test()
+
+    """
     return pytest.main(['-v', '--pyargs',
-                        'micromagneticmodel'])  # pragma: no cover
-
-
-__version__ = pkg_resources.get_distribution(__name__).version
-__dependencies__ = pkg_resources.require(__name__)
+                        'micromagneticmodel', '-l'])  # pragma: no cover
